Index: doc/styles/rules.txt
===================================================================
--- doc/styles/rules.txt	(revision 4649)
+++ doc/styles/rules.txt	(working copy)
@@ -525,14 +525,18 @@
 that the first member is the start of the route. 
                                                 
 === echo ===
-The echo action prints the element id plus a text to standard error. This can be
-used for quality checks and debugging purposes.
+The echo action prints the element id plus a text to stderr or to where directed by
+a logging configuration file. This can be used for quality checks and debugging
+purposes. When using a logging configuration file, the messages are logged
+with custom level ECHO (1200).
 [source]
   highway=motorway_link & oneway!=* { echo "motorway_link without oneway tag" }
 
 === echotags ===
-The echotags action prints the element id, all tags and values plus a text to standard error. 
-This can be used for style debugging purposes.
+The echotags action prints the element id, all tags and values plus a text to stderr
+or to where directed by a logging configuration file. This can be used for style
+debugging purposes. When using a logging configuration file, the messages are
+logged with custom level ECHO (1200).
 [source]
   highway=living_street { echotags "This is a living_street" }
 
Index: src/uk/me/parabola/mkgmap/osmstyle/actions/EchoAction.java
===================================================================
--- src/uk/me/parabola/mkgmap/osmstyle/actions/EchoAction.java	(revision 4649)
+++ src/uk/me/parabola/mkgmap/osmstyle/actions/EchoAction.java	(working copy)
@@ -16,9 +16,10 @@
 package uk.me.parabola.mkgmap.osmstyle.actions;
 
 import uk.me.parabola.mkgmap.reader.osm.Element;
+import uk.me.parabola.log.Logger;
 
 /**
- * Sends a message to the console.
+ * Logs a message.
  * 
  * @author Richard Fairhurst
  */
@@ -30,7 +31,7 @@
 	}
 
 	public boolean perform(Element el) {
-		System.err.println(el.getBasicLogInformation() + " " + value.build(el, el));
+		Logger.defaultLogger.echo(el.getBasicLogInformation() + " " + value.build(el, el));
 		return false;
 	}
 }
Index: src/uk/me/parabola/mkgmap/osmstyle/actions/EchoTagsAction.java
===================================================================
--- src/uk/me/parabola/mkgmap/osmstyle/actions/EchoTagsAction.java	(revision 4649)
+++ src/uk/me/parabola/mkgmap/osmstyle/actions/EchoTagsAction.java	(working copy)
@@ -14,9 +14,10 @@
 package uk.me.parabola.mkgmap.osmstyle.actions;
 
 import uk.me.parabola.mkgmap.reader.osm.Element;
+import uk.me.parabola.log.Logger;
 
 /**
- * Sends a message including the tags of an element to System.err.
+ * Logs a message including the tags of an element.
  * 
  * @author WanMil
  */
@@ -28,7 +29,7 @@
 	}
 
 	public boolean perform(Element el) {
-		System.err.println(el.getBasicLogInformation() + " " + el.toTagString() + " " + value.build(el, el));
+		Logger.defaultLogger.echo(el.getBasicLogInformation() + " " + el.toTagString() + " " + value.build(el, el));
 		return false;
 	}
 	
